@@ -17,18 +17,10 @@ package C4::ClassSource;
 # along with Koha; if not, see <https://www.gnu.org/licenses>.
 
 use Modern::Perl;
-
-use C4::Context;
-use C4::ClassSortRoutine qw( GetClassSortKey );
-
-use Koha::Cache::Memory::Lite;
-
-our ( @ISA, @EXPORT_OK );
+use base 'Exporter';
 
 BEGIN {
-    require Exporter;
-    @ISA       = qw(Exporter);
-    @EXPORT_OK = qw(
+    our @EXPORT_OK = qw(
         GetClassSources
         GetClassSource
         GetClassSortRule
@@ -36,6 +28,11 @@ BEGIN {
     );
 }
 
+use C4::Context;
+use C4::ClassSortRoutine qw( GetClassSortKey );
+
+use Koha::Cache::Memory::Lite;
+
 =head1 NAME
 
 C4::ClassSources - handle classification sources in Koha
