@@ -18,19 +18,16 @@ package C4::ClassSplitRoutine;
 # along with Koha; if not, see <https://www.gnu.org/licenses>.
 
 use Modern::Perl;
-
-use Class::Factory::Util;
-
-our ( @ISA, @EXPORT_OK );
+use base 'Exporter';
 
 BEGIN {
-    require Exporter;
-    @ISA       = qw(Exporter);
-    @EXPORT_OK = qw(
+    our @EXPORT_OK = qw(
         GetSplitRoutineNames
     );
 }
 
+use Class::Factory::Util;
+
 =head1 NAME
 
 C4::ClassSplitRoutine - base object for creation of classification splitting routines
