@@ -15,7 +15,7 @@ package C4::Form::MessagingPreferences;
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with Koha; if not, see <http://www.gnu.org/licenses>.
+# along with Koha; if not, see <https://www.gnu.org/licenses>.
 
 use strict;
 use warnings;
@@ -211,7 +211,7 @@ L<C4::Members::Messaging>, F<admin/categories.pl>, F<opac/opac-messaging.pl>, F<
 
 =head1 AUTHOR
 
-Koha Development Team <http://koha-community.org/>
+Koha Development Team <https://koha-community.org/>
 
 Galen Charlton <galen.charlton@liblime.com> refactoring code by Andrew Moore.
 
