@@ -19,28 +19,11 @@ package C4::HoldsQueue;
 
 # FIXME: expand perldoc, explain intended logic
 
-use strict;
-use warnings;
-
-use C4::Context;
-use C4::Circulation qw( GetBranchItemRule );
-use Koha::DateUtils qw( dt_from_string );
-use Koha::Hold::HoldsQueueItems;
-use Koha::Items;
-use Koha::Libraries;
-use Koha::Logger;
-use Koha::Patrons;
-
-use List::Util         qw( shuffle );
-use List::MoreUtils    qw( any );
-use Algorithm::Munkres qw();
-
-our ( @ISA, @EXPORT_OK );
+use Modern::Perl;
+use base 'Exporter';
 
 BEGIN {
-    require Exporter;
-    @ISA       = qw(Exporter);
-    @EXPORT_OK = qw(
+    our @EXPORT_OK = qw(
         CreateQueue
         GetHoldsQueueItems
 
@@ -52,6 +35,20 @@ BEGIN {
     );
 }
 
+use C4::Context;
+use C4::Circulation qw( GetBranchItemRule );
+use Koha::DateUtils qw( dt_from_string );
+use Koha::Hold::HoldsQueueItems;
+use Koha::HoldGroup;
+use Koha::Items;
+use Koha::Libraries;
+use Koha::Logger;
+use Koha::Patrons;
+
+use List::Util         qw( shuffle );
+use List::MoreUtils    qw( any );
+use Algorithm::Munkres qw();
+
 =head1 FUNCTIONS
 
 =head2 TransportCostMatrix
@@ -250,6 +247,9 @@ that have one or more unfilled hold requests.
 sub GetBibsWithPendingHoldRequests {
     my $dbh = C4::Context->dbh;
 
+    my $skip_non_target_holds_query     = Koha::HoldGroup::skip_non_target_holds_query('sql');
+    my $skip_non_target_holds_query_sql = $skip_non_target_holds_query ? " $skip_non_target_holds_query" : '';
+
     my $bib_query = "SELECT DISTINCT biblionumber
                      FROM reserves
                      WHERE found IS NULL
@@ -257,12 +257,12 @@ sub GetBibsWithPendingHoldRequests {
                      AND reservedate <= CURRENT_DATE()
                      AND suspend = 0
                      AND reserve_id NOT IN (SELECT reserve_id FROM hold_fill_targets)
+                     $skip_non_target_holds_query_sql
                      ";
     my $sth = $dbh->prepare($bib_query);
 
     $sth->execute();
     my $biblionumbers = $sth->fetchall_arrayref();
-
     return [ map { $_->[0] } @$biblionumbers ];
 }
 
@@ -294,6 +294,9 @@ sub GetPendingHoldRequestsForBib {
 
     my $dbh = C4::Context->dbh;
 
+    my $skip_non_target_holds_query     = Koha::HoldGroup::skip_non_target_holds_query('sql');
+    my $skip_non_target_holds_query_sql = $skip_non_target_holds_query ? " $skip_non_target_holds_query" : '';
+
     my $request_query = "SELECT biblionumber, borrowernumber, itemnumber, priority, reserve_id, reserves.branchcode,
                                 reservedate, reservenotes, borrowers.branchcode AS borrowerbranch, itemtype, item_level_hold, item_group_id
                          FROM reserves
@@ -304,6 +307,7 @@ sub GetPendingHoldRequestsForBib {
                          AND reservedate <= CURRENT_DATE()
                          AND suspend = 0 ";
     $request_query .= "AND reserve_id NOT IN (SELECT reserve_id FROM hold_fill_targets) " if $unallocated;
+    $request_query .= $skip_non_target_holds_query_sql;
     $request_query .= "ORDER BY priority";
     my $sth = $dbh->prepare($request_query);
     $sth->execute($biblionumber);
