@@ -17,37 +17,11 @@ package C4::ImportBatch;
 # You should have received a copy of the GNU General Public License
 # along with Koha; if not, see <https://www.gnu.org/licenses>.
 
-use strict;
-use warnings;
-
-use C4::Context;
-use C4::Koha   qw( GetNormalizedISBN );
-use C4::Biblio qw(
-    AddBiblio
-    DelBiblio
-    GetMarcFromKohaField
-    GetXmlBiblio
-    ModBiblio
-    TransformMarcToKoha
-);
-use C4::Items   qw( AddItemFromMarc ModItemFromMarc );
-use C4::Charset qw( MarcToUTF8Record SetUTF8Flag StripNonXmlChars );
-use C4::AuthoritiesMarc
-    qw( AddAuthority GuessAuthTypeCode GetAuthorityXML ModAuthority DelAuthority GetAuthorizedHeading );
-use C4::MarcModificationTemplates qw( ModifyRecordWithTemplate );
-use Koha::BackgroundJob::BatchUpdateBiblioHoldsQueue;
-use Koha::Items;
-use Koha::SearchEngine;
-use Koha::SearchEngine::Indexer;
-use Koha::Plugins::Handler;
-use Koha::Logger;
-
-our ( @ISA, @EXPORT_OK );
+use Modern::Perl;
+use base 'Exporter';
 
 BEGIN {
-    require Exporter;
-    @ISA       = qw(Exporter);
-    @EXPORT_OK = qw(
+    our @EXPORT_OK = qw(
         GetZ3950BatchId
         GetWebserviceBatchId
         GetImportRecordMarc
@@ -97,6 +71,28 @@ BEGIN {
     );
 }
 
+use C4::Context;
+use C4::Koha   qw( GetNormalizedISBN );
+use C4::Biblio qw(
+    AddBiblio
+    DelBiblio
+    GetMarcFromKohaField
+    GetXmlBiblio
+    ModBiblio
+    TransformMarcToKoha
+);
+use C4::Items   qw( AddItemFromMarc ModItemFromMarc );
+use C4::Charset qw( MarcToUTF8Record SetUTF8Flag StripNonXmlChars );
+use C4::AuthoritiesMarc
+    qw( AddAuthority GuessAuthTypeCode GetAuthorityXML ModAuthority DelAuthority GetAuthorizedHeading );
+use C4::MarcModificationTemplates qw( ModifyRecordWithTemplate );
+use Koha::BackgroundJob::BatchUpdateBiblioHoldsQueue;
+use Koha::Items;
+use Koha::SearchEngine;
+use Koha::SearchEngine::Indexer;
+use Koha::Plugins::Handler;
+use Koha::Logger;
+
 =head1 NAME
 
 C4::ImportBatch - manage batches of imported MARC records
