@@ -21,6 +21,47 @@ package C4::Reserves;
 # along with Koha; if not, see <https://www.gnu.org/licenses>.
 
 use Modern::Perl;
+use base 'Exporter';
+
+BEGIN {
+    our @EXPORT_OK = qw(
+        AddReserve
+
+        GetReserveStatus
+
+        ChargeReserveFee
+        GetReserveFee
+
+        ModReserveAffect
+        ModReserve
+        ModReserveStatus
+        ModReserveCancelAll
+        ModReserveMinusPriority
+        MoveReserve
+
+        CheckReserves
+        CanBookBeReserved
+        CanItemBeReserved
+        CancelExpiredReserves
+
+        AutoUnsuspendReserves
+
+        IsAvailableForItemLevelRequest
+        ItemsAnyAvailableAndNotRestricted
+
+        AlterPriority
+        ToggleLowestPriority
+
+        ReserveSlip
+        SuspendAll
+
+        CalculatePriority
+
+        GetMaxPatronHoldsForRecord
+
+        MergeHolds
+    );
+}
 
 use JSON qw( to_json );
 
@@ -42,6 +83,7 @@ use Koha::CirculationRules;
 use Koha::Database;
 use Koha::DateUtils qw( dt_from_string output_pref );
 use Koha::Holds;
+use Koha::HoldGroup;
 use Koha::ItemTypes;
 use Koha::Items;
 use Koha::Libraries;
@@ -98,50 +140,6 @@ This modules provides some functions to deal with reservations.
 
 =cut
 
-our ( @ISA, @EXPORT_OK );
-
-BEGIN {
-    require Exporter;
-    @ISA       = qw(Exporter);
-    @EXPORT_OK = qw(
-        AddReserve
-
-        GetReserveStatus
-
-        ChargeReserveFee
-        GetReserveFee
-
-        ModReserveAffect
-        ModReserve
-        ModReserveStatus
-        ModReserveCancelAll
-        ModReserveMinusPriority
-        MoveReserve
-
-        CheckReserves
-        CanBookBeReserved
-        CanItemBeReserved
-        CancelExpiredReserves
-
-        AutoUnsuspendReserves
-
-        IsAvailableForItemLevelRequest
-        ItemsAnyAvailableAndNotRestricted
-
-        AlterPriority
-        ToggleLowestPriority
-
-        ReserveSlip
-        SuspendAll
-
-        CalculatePriority
-
-        GetMaxPatronHoldsForRecord
-
-        MergeHolds
-    );
-}
-
 =head2 AddReserve
 
     AddReserve(
@@ -407,7 +405,7 @@ sub CanBookBeReserved {
 
         $reservesallowed = ( $reservesallowed eq '' ) ? undef : $reservesallowed;
 
-        my $count = $patron->holds->search(
+        my $count = $patron->holds->count_holds(
             {
                 '-or' => [
                     { 'me.itemtype' => $params->{itemtype} },
@@ -415,7 +413,7 @@ sub CanBookBeReserved {
                 ]
             },
             { join => ['item'] }
-        )->count;
+        );
 
         return { status => '' }
             if defined $reservesallowed and $reservesallowed < $count + 1;
@@ -587,21 +585,21 @@ sub CanItemBeReserved {
                 borrowernumber => $patron->borrowernumber,
                 biblionumber   => $item->biblionumber,
             };
-            my $holds = Koha::Holds->search($search_params);
+            my $holds_count = Koha::Holds->count_holds($search_params);
             return _cache { status => "tooManyHoldsForThisRecord", limit => $holds_per_record }
-                if $holds->count() >= $holds_per_record;
+                if $holds_count >= $holds_per_record;
         }
     }
 
     if ( !$params->{ignore_hold_counts} && defined $holds_per_day && $holds_per_day ne '' ) {
-        my $today_holds = Koha::Holds->search(
+        my $today_holds_count = Koha::Holds->count_holds(
             {
                 borrowernumber => $patron->borrowernumber,
                 reservedate    => dt_from_string->date
             }
         );
         return _cache { status => 'tooManyReservesToday', limit => $holds_per_day }
-            if $today_holds->count() >= $holds_per_day;
+            if $today_holds_count >= $holds_per_day;
     }
 
     # we check if it's ok or not
@@ -1368,8 +1366,12 @@ sub ModReserveAffect {
 
     $hold->itemnumber($itemnumber);
 
+    my @reserve_ids;
+    push @reserve_ids, $hold->reserve_id;
+
     if ($transferToDo) {
         $hold->set_transfer();
+        $hold->set_as_hold_group_target();
     } elsif ( C4::Context->preference('HoldsNeedProcessingSIP')
         && C4::Context->interface eq 'sip'
         && !$already_on_shelf )
@@ -1382,6 +1384,8 @@ sub ModReserveAffect {
         # Complete transfer if one exists
         my $transfer = $hold->item->get_transfer;
         $transfer->receive if $transfer;
+
+        $hold->set_as_hold_group_target();
     }
 
     _koha_notify_hold_changed($hold) if $notify_library;
@@ -1395,8 +1399,9 @@ sub ModReserveAffect {
         CartToShelf($itemnumber);
     }
 
-    my $std = $dbh->prepare(
-        q{
+    foreach my $id (@reserve_ids) {
+        my $std = $dbh->prepare(
+            q{
         DELETE  q, t
         FROM    tmp_holdsqueue q
         INNER JOIN hold_fill_targets t
@@ -1406,9 +1411,10 @@ sub ModReserveAffect {
             AND q.item_level_request = t.item_level_request
             AND q.holdingbranch = t.source_branchcode
         WHERE t.reserve_id = ?
+            }
+        );
+        $std->execute($id);
     }
-    );
-    $std->execute( $hold->reserve_id );
 
     logaction( 'HOLDS', 'MODIFY', $hold->reserve_id, $hold, undef, $original )
         if C4::Context->preference('HoldsLog');
@@ -1868,6 +1874,9 @@ sub _Findgroupreserve {
     my ( $biblionumber, $itemnumber, $lookahead, $ignore_borrowers ) = @_;
     my $dbh = C4::Context->dbh;
 
+    my $skip_non_target_holds_query     = Koha::HoldGroup::skip_non_target_holds_query('sql');
+    my $skip_non_target_holds_query_sql = $skip_non_target_holds_query ? " $skip_non_target_holds_query" : '';
+
     # check for targeted match form the holds queue
     my $hold_target_query = qq{
         SELECT reserves.biblionumber        AS biblionumber,
@@ -1884,7 +1893,8 @@ sub _Findgroupreserve {
                reserves.reserve_id          AS reserve_id,
                reserves.itemtype            AS itemtype,
                reserves.non_priority        AS non_priority,
-               reserves.item_group_id           AS item_group_id
+               reserves.item_group_id       AS item_group_id,
+               reserves.hold_group_id       AS hold_group_id
         FROM reserves
         JOIN biblioitems USING (biblionumber)
         JOIN hold_fill_targets USING (reserve_id)
@@ -1893,6 +1903,7 @@ sub _Findgroupreserve {
         AND hold_fill_targets.itemnumber = ?
         AND reservedate <= DATE_ADD(NOW(),INTERVAL ? DAY)
         AND suspend = 0
+        $skip_non_target_holds_query_sql
         ORDER BY priority
     };
     my $sth = $dbh->prepare($hold_target_query);
@@ -1919,12 +1930,14 @@ sub _Findgroupreserve {
                reserves.reserve_id                 AS reserve_id,
                reserves.itemtype                   AS itemtype,
                reserves.non_priority               AS non_priority,
-               reserves.item_group_id              AS item_group_id
+               reserves.item_group_id              AS item_group_id,
+               reserves.hold_group_id              AS hold_group_id
         FROM reserves
         WHERE reserves.biblionumber = ?
           AND (reserves.itemnumber IS NULL OR reserves.itemnumber = ?)
           AND reserves.reservedate <= DATE_ADD(NOW(),INTERVAL ? DAY)
           AND suspend = 0
+          $skip_non_target_holds_query_sql
           ORDER BY priority
     };
     $sth = $dbh->prepare($query);
