@@ -3,7 +3,7 @@ package C4::SIP::Logger;
 use Modern::Perl;
 
 use base 'Exporter';
-our @EXPORT_OK = qw ( get_logger set_logger );
+BEGIN { our @EXPORT_OK = qw ( get_logger set_logger ); }
 
 our $activeSIPServer;
 our $activeLogger;
