@@ -19,6 +19,41 @@ package C4::Serials;
 # along with Koha; if not, see <https://www.gnu.org/licenses>.
 
 use Modern::Perl;
+use base 'Exporter';
+
+BEGIN {
+    our @EXPORT_OK = qw(
+        NewSubscription    ModSubscription    DelSubscription
+        GetSubscription    CountSubscriptionFromBiblionumber      GetSubscriptionsFromBiblionumber
+        SearchSubscriptions
+        GetFullSubscriptionsFromBiblionumber   GetFullSubscription ModSubscriptionHistory
+        HasSubscriptionStrictlyExpired HasSubscriptionExpired GetExpirationDate abouttoexpire
+        GetFictiveIssueNumber
+        GetSubscriptionHistoryFromSubscriptionId
+
+        GetNextSeq GetSeq NewIssue           GetSerials
+        GetLatestSerials   ModSerialStatus    GetNextDate
+        CloseSubscription ReopenSubscription
+        subscriptionCurrentlyOnOrder
+        can_claim_subscription can_edit_subscription can_show_subscription
+        GetSerials2
+        GetSubscriptionLength ReNewSubscription  GetLateOrMissingIssues
+        GetSerialInformation                   AddItem2Serial
+        PrepareSerialsData GetNextExpected    ModNextExpected
+        GetSubscriptionIrregularities
+        GetPreviousSerialid
+
+        GetSuppliersWithLateIssues
+        getroutinglist     delroutingmember   addroutingmember
+        reorder_members
+        check_routing updateClaim
+        CountIssues
+        HasItems
+
+        findSerialsByStatus
+
+    );
+}
 
 use Carp       qw( croak );
 use Date::Calc qw(
@@ -73,44 +108,6 @@ use constant MISSING_STATUSES => (
     MISSING_LOST
 );
 
-our ( @ISA, @EXPORT_OK );
-
-BEGIN {
-    require Exporter;
-    @ISA       = qw(Exporter);
-    @EXPORT_OK = qw(
-        NewSubscription    ModSubscription    DelSubscription
-        GetSubscription    CountSubscriptionFromBiblionumber      GetSubscriptionsFromBiblionumber
-        SearchSubscriptions
-        GetFullSubscriptionsFromBiblionumber   GetFullSubscription ModSubscriptionHistory
-        HasSubscriptionStrictlyExpired HasSubscriptionExpired GetExpirationDate abouttoexpire
-        GetFictiveIssueNumber
-        GetSubscriptionHistoryFromSubscriptionId
-
-        GetNextSeq GetSeq NewIssue           GetSerials
-        GetLatestSerials   ModSerialStatus    GetNextDate
-        CloseSubscription ReopenSubscription
-        subscriptionCurrentlyOnOrder
-        can_claim_subscription can_edit_subscription can_show_subscription
-        GetSerials2
-        GetSubscriptionLength ReNewSubscription  GetLateOrMissingIssues
-        GetSerialInformation                   AddItem2Serial
-        PrepareSerialsData GetNextExpected    ModNextExpected
-        GetSubscriptionIrregularities
-        GetPreviousSerialid
-
-        GetSuppliersWithLateIssues
-        getroutinglist     delroutingmember   addroutingmember
-        reorder_members
-        check_routing updateClaim
-        CountIssues
-        HasItems
-
-        findSerialsByStatus
-
-    );
-}
-
 =head1 NAME
 
 C4::Serials - Serials Module Functions
@@ -1842,10 +1839,9 @@ sub DelSubscription {
 
     Koha::AdditionalFieldValues->search(
         {
-            'field.tablename' => 'subscription',
+            'me.record_table' => 'subscription',
             'me.record_id'    => $subscriptionid,
-        },
-        { join => 'field' }
+        }
     )->delete;
 
     logaction( "SERIAL", "DELETE", $subscriptionid, "" ) if C4::Context->preference("SubscriptionLog");
