@@ -38,7 +38,7 @@ sub _type { 'AdditionalFieldValue' }
 
 =head1 AUTHOR
 
-Koha Development Team <http://koha-community.org/>
+Koha Development Team <https://koha-community.org/>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -56,7 +56,7 @@ WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License along
-with Koha; if not, see <http://www.gnu.org/licenses>.
+with Koha; if not, see <https://www.gnu.org/licenses>.
 
 =head1 SEE ALSO
 
