@@ -125,6 +125,9 @@ sub enqueue {
     my $job_queue   = $params->{job_queue}   // 'default';
     my $json        = $self->json;
 
+    # session_id must not be logged
+    delete $job_context->{session_id};
+
     my $borrowernumber = ( C4::Context->userenv ) ? C4::Context->userenv->{number} : undef;
     $job_context->{interface} = C4::Context->interface;
     my $json_context = $json->encode($job_context);
@@ -456,6 +459,7 @@ sub core_types_to_classes {
         marc_import_revert_batch            => 'Koha::BackgroundJob::MARCImportRevertBatch',
         pseudonymize_statistic              => 'Koha::BackgroundJob::PseudonymizeStatistic',
         import_from_kbart_file              => 'Koha::BackgroundJob::ImportKBARTFile',
+        file_transport_test                 => 'Koha::BackgroundJob::TestTransport',
     };
 }
 
