@@ -25,7 +25,7 @@ sub process {
 
     $self->start;
 
-    my $mmtid = $args->{mmtid};
+    my $mmtid      = $args->{mmtid};
     my @record_ids = @{ $args->{record_ids} };
 
     my $report = {
@@ -34,7 +34,7 @@ sub process {
     };
     my @messages;
     my $schema = Koha::Database->new->schema;
-    RECORD_IDS: for my $record_id ( sort { $a <=> $b } @record_ids ) {
+RECORD_IDS: for my $record_id ( sort { $a <=> $b } @record_ids ) {
 
         last if $self->get_from_storage->status eq 'cancelled';
 
@@ -43,23 +43,20 @@ sub process {
         $schema->storage->txn_begin;
 
         my $authid = $record_id;
-        eval {
-            C4::AuthoritiesMarc::DelAuthority(
-                { authid => $authid, skip_record_index => 1 } );
-        };
-        if ( $@ ) {
+        eval { C4::AuthoritiesMarc::DelAuthority( { authid => $authid, skip_record_index => 1 } ); };
+        if ($@) {
             push @messages, {
-                type => 'error',
-                code => 'authority_not_deleted',
+                type   => 'error',
+                code   => 'authority_not_deleted',
                 authid => $authid,
-                error => "$@",
+                error  => "$@",
             };
             $schema->storage->txn_rollback;
             next;
         } else {
             push @messages, {
-                type => 'success',
-                code => 'authority_deleted',
+                type   => 'success',
+                code   => 'authority_deleted',
                 authid => $authid,
             };
             $report->{total_success}++;
@@ -70,34 +67,35 @@ sub process {
     }
 
     my @deleted_authids =
-      map { $_->{code} eq 'authority_deleted' ? $_->{authid} : () }
-          @messages;
+        map { $_->{code} eq 'authority_deleted' ? $_->{authid} : () } @messages;
 
-    if ( @deleted_authids ) {
-        my $indexer = Koha::SearchEngine::Indexer->new({ index => $Koha::SearchEngine::AUTHORITIES_INDEX });
+    if (@deleted_authids) {
+        my $indexer = Koha::SearchEngine::Indexer->new( { index => $Koha::SearchEngine::AUTHORITIES_INDEX } );
         $indexer->index_records( \@deleted_authids, "recordDelete", "authorityserver" );
     }
 
     my $data = $self->decoded_data;
     $data->{messages} = \@messages;
-    $data->{report} = $report;
+    $data->{report}   = $report;
 
-    $self->finish( $data );
+    $self->finish($data);
 }
 
 sub enqueue {
-    my ( $self, $args) = @_;
+    my ( $self, $args ) = @_;
 
     # TODO Raise exception instead
     return unless exists $args->{record_ids};
 
     my @record_ids = @{ $args->{record_ids} };
 
-    $self->SUPER::enqueue({
-        job_size  => scalar @record_ids,
-        job_args  => {record_ids => \@record_ids,},
-        job_queue => 'long_tasks',
-    });
+    $self->SUPER::enqueue(
+        {
+            job_size  => scalar @record_ids,
+            job_args  => { record_ids => \@record_ids, },
+            job_queue => 'long_tasks',
+        }
+    );
 }
 
 1;
