@@ -1,7 +1,7 @@
 package Koha::Devel::Files;
 
 use Modern::Perl;
-our ( @ISA, @EXPORT_OK );
+use Array::Utils qw( array_minus );
 
 =head1 NAME
 
@@ -11,9 +11,9 @@ Koha::Devel::Files - A utility module for managing and filtering file lists in t
 
     use Koha::Devel::Files;
 
-    my $file_manager = Koha::Devel::Files->new({ context => 'tidy' });
+    my $file_manager = Koha::Devel::Files->new( { context => 'tidy' } );
 
-    my @perl_files = $file_manager->ls_perl_files($git_range);
+    my @perl_files = $file_manager->ls_perl_files();
     my @js_files   = $file_manager->ls_js_files();
     my @tt_files   = $file_manager->ls_tt_files();
 
@@ -110,7 +110,7 @@ my $exceptions = {
 
 =head2 new
 
-    my $file_manager = Koha::Devel::Files->new({ context => 'tidy' });
+    my $file_manager = Koha::Devel::Files->new( { context => 'tidy' } );
 
 Creates a new instance of Koha::Devel::Files. The constructor accepts a hash reference with a 'context' key, which specifies the context for file exclusions.
 
@@ -146,19 +146,79 @@ sub build_git_exclude {
     return $exclude_list;
 }
 
+=head2 remove_exceptions
+
+    @files = $file_manager->remove_exceptions($files, $filetype);
+
+Remove from exceptions from the original file list.
+
+=cut
+
+sub remove_exceptions {
+    my ( $self, $files, $filetype ) = @_;
+    my @files = @$files;
+    return () unless @files;
+    my @exceptions = @{ $exceptions->{$filetype}->{ $self->{context} } // [] };
+    if (@exceptions) {
+        my $cmd             = qq{git ls-files @exceptions};
+        my @exception_files = qx{$cmd};
+        chomp for @exception_files;
+        @files = array_minus @files, @exception_files;
+    }
+    return @files;
+}
+
+=head2 ls_files
+
+    my @files = $file_manager->ls_files( $filetype, $git_range );
+
+Lists files that have been modified within a specified Git range. If no range is provided, it lists all Perl files, excluding those specified in the exceptions.
+
+=cut
+
+sub ls_files {
+    my ( $self, $filetype, $git_range ) = @_;
+    my @files;
+    if ($git_range) {
+        $git_range =~ s|\.\.| |;
+        my @modified_files = qx{git diff --name-only $git_range};
+        chomp for @modified_files;
+        if ( $filetype eq 'pl' ) {
+            push @files, grep { -e && /\.(pl|PL|pm|t)$/ } @modified_files;
+            push @files, grep { -e && /^(svc|opac\/svc)/ } @modified_files;
+        } elsif ( $filetype eq 'js' ) {
+            push @files, grep { -e && /\.(js|ts|vue)$/ } @modified_files;
+        } elsif ( $filetype eq 'tt' ) {
+            push @files, grep { -e && /\.(tt|inc)$/ } @modified_files;
+        }
+        @files = $self->remove_exceptions( \@files, $filetype );
+    } else {
+        if ( $filetype eq 'pl' ) {
+            @files = $self->ls_perl_files;
+        } elsif ( $filetype eq 'js' ) {
+            @files = $self->ls_js_files;
+        } elsif ( $filetype eq 'tt' ) {
+            @files = $self->ls_tt_files;
+        }
+    }
+    return @files;
+}
+
 =head2 ls_perl_files
 
-    my @perl_files = $file_manager->ls_perl_files($git_range);
+    my @perl_files = $file_manager->ls_perl_files();
 
-Lists Perl files (with extensions .pl, .PL, .pm, .t) that have been modified within a specified Git range. If no range is provided, it lists all Perl files, excluding those specified in the exceptions.
+Lists Perl files (with extensions .pl, .PL, .pm, .t) in the repository, excluding those specified in the exceptions.
 
 =cut
 
 sub ls_perl_files {
     my ($self) = @_;
-    my $cmd = sprintf q{git ls-files '*.pl' '*.PL' '*.pm' '*.t' svc opac/svc debian/build-git-snapshot %s},
+    my @files;
+    my $cmd =
+        sprintf q{git ls-files '*.pl' '*.PL' '*.pm' '*.t' svc opac/svc opac/unapi debian/build-git-snapshot %s},
         $self->build_git_exclude('pl');
-    my @files = qx{$cmd};
+    @files = qx{$cmd};
     chomp for @files;
     return @files;
 }
@@ -272,7 +332,7 @@ sub get_filetype {
     return 'pl' if $file =~ m{^svc}  || $file =~ m{^opac/svc};
     return 'pl' if $file =~ m{\.pl$} || $file =~ m{\.pm} || $file =~ m{\.t$};
     return 'pl' if $file =~ m{\.PL$};
-    return 'pl' if $file =~ m{debian/build-git-snapshot};
+    return 'pl' if $file =~ m{debian/build-git-snapshot} || $file =~ m{opac/unapi};
 
     return 'js' if $file =~ m{\.js$} || $file =~ m{\.ts$} || $file =~ m{\.vue$};
 
