@@ -17,9 +17,19 @@ package Koha::EDI;
 # You should have received a copy of the GNU General Public License
 # along with Koha; if not, see <https://www.gnu.org/licenses>.
 
-use strict;
-use warnings;
+use Modern::Perl;
 use base qw(Exporter);
+
+BEGIN {
+    our @EXPORT_OK = qw(
+        process_quote
+        process_invoice
+        process_ordrsp
+        create_edi_order
+        get_edifact_ean
+    );
+}
+
 use utf8;
 use English qw{ -no_match_vars };
 use Business::ISBN;
@@ -48,20 +58,6 @@ use Koha::Util::FrameworkPlugin qw( biblio_008 );
 
 our $VERSION = 1.1;
 
-our ( @ISA, @EXPORT_OK );
-
-BEGIN {
-    require Exporter;
-    @ISA       = qw(Exporter);
-    @EXPORT_OK = qw(
-        process_quote
-        process_invoice
-        process_ordrsp
-        create_edi_order
-        get_edifact_ean
-    );
-}
-
 sub create_edi_order {
     my $parameters = shift;
     my $basketno   = $parameters->{basketno};
@@ -95,6 +91,32 @@ sub create_edi_order {
         }
     )->single;
 
+    # Check for duplicate PO numbers when po_is_basketname is enabled
+    if ( $vendor && $vendor->po_is_basketname ) {
+        my $basket = $orderlines[0]->basketno;
+        if ( $basket->basketname ) {
+            my $existing_basket = $schema->resultset('Aqbasket')->search(
+                {
+                    basketname   => $basket->basketname,
+                    booksellerid => $basket->booksellerid,
+                    basketno     => { '!=' => $basketno },    # Exclude current basket
+                }
+            )->first;
+
+            if ($existing_basket) {
+                $logger->error( "EDI order blocked for basket $basketno due to duplicate PO number '"
+                        . $basket->basketname
+                        . "' (existing basket: "
+                        . $existing_basket->basketno
+                        . ")" );
+                return {
+                    error     => "duplicate_po_number", existing_basket => $existing_basket->basketno,
+                    po_number => $basket->basketname
+                };
+            }
+        }
+    }
+
     my $ean_search_keys = { ean => $ean, };
     if ($branchcode) {
         $ean_search_keys->{branchcode} = $branchcode;
@@ -647,16 +669,72 @@ sub process_quote {
     my $schema         = Koha::Database->new()->schema();
     my $message_count  = 0;
     my $split_message;
-    my @added_baskets;    # if auto & multiple baskets need to order all
+    my @added_baskets;                # if auto & multiple baskets need to order all
+    my %baskets_with_po_conflicts;    # track baskets that have PO number conflicts
+
+    # Get vendor EDI account configuration
+    my $v = $schema->resultset('VendorEdiAccount')->search(
+        {
+            vendor_id => $quote_message->vendor_id,
+        }
+    )->single;
 
     if ( @{$messages} && $quote_message->vendor_id ) {
+
         foreach my $msg ( @{$messages} ) {
             ++$message_count;
+
+            # Determine basket name based on vendor configuration
+            my $basket_name = $quote_message->filename;
+            my $purchase_order_number;
+            my $existing_basket;
+
+            if ( $v && $v->po_is_basketname ) {
+                $purchase_order_number = $msg->purchase_order_number;
+                if ($purchase_order_number) {
+                    $basket_name = $purchase_order_number;
+
+                    # Check for duplicate purchase order numbers for this vendor (including closed baskets)
+                    $existing_basket = $schema->resultset('Aqbasket')->search(
+                        {
+                            basketname   => $basket_name,
+                            booksellerid => $quote_message->vendor_id,
+                        }
+                    )->first;
+
+                    if ($existing_basket) {
+
+                        # Log error for duplicate purchase order number but continue processing
+                        my $rff_segment = "RFF+ON:$purchase_order_number";
+                        $quote_message->add_to_edifact_errors(
+                            {
+                                section => $rff_segment,
+                                details => "Duplicate purchase order number '$purchase_order_number' found for vendor "
+                                    . $quote_message->vendor_id . "."
+                            }
+                        );
+                        $logger->warn( "Duplicate purchase order number '$purchase_order_number' for vendor "
+                                . $quote_message->vendor_id
+                                . " (existing basket: "
+                                . $existing_basket->basketno
+                                . ")" );
+                    }
+                }
+            }
+
             my $basketno = NewBasket(
-                $quote_message->vendor_id, 0, $quote_message->filename, q{},
+                $quote_message->vendor_id, 0, $basket_name, q{},
                 q{} . q{}
             );
             push @added_baskets, $basketno;
+
+            # Record if this basket has a PO conflict (for auto_orders blocking)
+            if ($existing_basket) {
+                $baskets_with_po_conflicts{$basketno} = {
+                    po_number       => $purchase_order_number,
+                    existing_basket => $existing_basket->basketno
+                };
+            }
             if ( $message_count > 1 ) {
                 my $m_filename = $quote_message->filename;
                 $m_filename .= "_$message_count";
@@ -695,15 +773,22 @@ sub process_quote {
     $quote_message->status($status);
     $quote_message->update;    # status and basketno link
                                # Do we automatically generate orders for this vendor
-    my $v = $schema->resultset('VendorEdiAccount')->search(
-        {
-            vendor_id => $quote_message->vendor_id,
-        }
-    )->single;
-    if ( $v->auto_orders ) {
+    if ( $v && $v->auto_orders ) {
         for my $i ( 0 .. $#added_baskets ) {
             my $basketno = $added_baskets[$i];
 
+            # Check if this basket has a PO number conflict
+            if ( exists $baskets_with_po_conflicts{$basketno} ) {
+                my $conflict_info = $baskets_with_po_conflicts{$basketno};
+                $logger->warn( "Auto-order blocked for basket $basketno due to duplicate PO number '"
+                        . $conflict_info->{po_number}
+                        . "' (existing basket: "
+                        . $conflict_info->{existing_basket}
+                        . ")" );
+                $logger->info("Basket $basketno remains open due to PO number conflict");
+                next;
+            }
+
             # Use the correct buyer_ean for each message/basket
             my $buyer_ean = $messages->[$i] ? $messages->[$i]->buyer_ean : $messages->[0]->buyer_ean;
 
