@@ -40,6 +40,7 @@ use Koha::Plugins;
 use Koha::BackgroundJob::BatchUpdateBiblioHoldsQueue;
 
 use Koha::Exceptions;
+use Koha::HoldGroups;
 use Koha::Exceptions::Hold;
 
 use base qw(Koha::Object);
@@ -178,6 +179,159 @@ sub delete {
     return $deleted;
 }
 
+=head3 move_hold
+
+$hold->move_hold();
+
+=cut
+
+sub move_hold {
+    my ( $self, $args ) = @_;
+
+    my $original              = $self;
+    my $original_biblionumber = $self->biblionumber;
+
+    my $found = $original->found // '';
+
+    if ( $found eq 'W' ) {
+        return { success => 0, error => 'Cannot move a waiting hold' };
+    }
+
+    if ( $found eq 'T' ) {
+        return { success => 0, error => 'Cannot move a hold in transit' };
+    }
+
+    my $patron = Koha::Patrons->find( { borrowernumber => $self->borrowernumber } );
+    return { success => 0, error => 'Missing patron or target' } unless $patron;
+
+    my ( $new_biblionumber, $new_itemnumber, $item, $canReserve );
+
+    if ( $args->{new_itemnumber} ) {
+        $item = Koha::Items->find( { itemnumber => $args->{new_itemnumber} } )
+            or return { success => 0, error => 'Target item not found' };
+
+        $new_itemnumber   = $item->itemnumber;
+        $new_biblionumber = $item->biblionumber;
+
+        $canReserve = C4::Reserves::CanItemBeReserved( $patron, $item, $self->branchcode, { ignore_hold_counts => 1 } );
+    } elsif ( $args->{new_biblionumber} ) {
+        $new_biblionumber = $args->{new_biblionumber};
+
+        $canReserve = C4::Reserves::CanBookBeReserved(
+            $patron->borrowernumber, $new_biblionumber, $self->branchcode,
+            { ignore_hold_counts => 1 }
+        );
+    } else {
+        return { success => 0, error => 'Missing itemnumber or biblionumber' };
+    }
+
+    return { success => 0, error => $canReserve->{status} }
+        unless $canReserve->{status} eq 'OK';
+
+    my $max = Koha::Holds->search(
+        { biblionumber => $new_biblionumber },
+        { order_by     => { -desc => 'priority' }, rows => 1 }
+    )->next;
+    my $base_priority = $max ? $max->priority : 0;
+    my $priority      = $base_priority + 1;
+    my $new_priority  = C4::Reserves::_ShiftPriority( $new_biblionumber, $priority );
+
+    $self->update(
+        {
+            itemnumber   => $new_itemnumber,     # undef for biblio-level is fine
+            biblionumber => $new_biblionumber,
+            priority     => $new_priority,
+        }
+    );
+
+    C4::Log::logaction( 'HOLDS', 'MODIFY', $self->reserve_id, $self, undef, $original )
+        if C4::Context->preference('HoldsLog');
+
+    return { success => 1, hold => $self };
+}
+
+=head3 cleanup_hold_group
+
+$self->cleanup_hold_group;
+
+Check if a hold group is left with a single or zero holds. Delete hold_group if so.
+Accepts an optional $hold_group_id that, if defined, uses that instead of self->hold_group_id
+
+=cut
+
+sub cleanup_hold_group {
+    my ( $self, $hold_group_id ) = @_;
+
+    my $hold_group_id_to_check = $hold_group_id // $self->hold_group_id;
+    my $hold_group             = Koha::HoldGroups->find($hold_group_id_to_check);
+    return unless $hold_group;
+
+    if ( $hold_group->holds->count <= 1 ) {
+        $hold_group->delete();
+    }
+}
+
+=head3 set_as_hold_group_target
+
+$self->set_as_hold_group_target;
+
+Sets this hold and its' hold group's target
+
+=cut
+
+sub set_as_hold_group_target {
+    my ($self) = @_;
+
+    if ( $self->hold_group && !$self->hold_group->target_hold_id && C4::Context->preference("DisplayAddHoldGroups") ) {
+        $self->_result->create_related(
+            'hold_groups_target_hold',
+            { hold_group_id => $self->hold_group->hold_group_id }
+        );
+    }
+}
+
+=head3 remove_as_hold_group_target
+
+$self->remove_as_hold_group_target;
+
+Removes this hold as the target of its hold group if it is currently set as such,
+and if the DisplayAddHoldGroups system preference is enabled.
+
+=cut
+
+sub remove_as_hold_group_target {
+    my ($self) = @_;
+
+    if (   $self->hold_group
+        && $self->hold_group->target_hold_id
+        && $self->hold_group->target_hold_id eq $self->reserve_id
+        && C4::Context->preference("DisplayAddHoldGroups") )
+    {
+        $self->_result->find_related(
+            'hold_groups_target_hold',
+            { hold_group_id => $self->hold_group->hold_group_id, reserve_id => $self->reserve_id }
+        )->delete();
+    }
+}
+
+=head3 is_hold_group_target
+
+$self->is_hold_group_target;
+
+Returns whether this hold is its hold group target
+
+=cut
+
+sub is_hold_group_target {
+    my ($self) = @_;
+
+    return 1
+        if $self->hold_group
+        && $self->hold_group->target_hold_id
+        && $self->hold_group->target_hold_id eq $self->reserve_id;
+    return 0;
+}
+
 =head3 set_transfer
 
 =cut
@@ -672,9 +826,10 @@ sub cancellation_requested {
 
 my $cancel_hold = $hold->cancel(
     {
-        [ charge_cancel_fee   => 1||0, ]
-        [ cancellation_reason => $cancellation_reason, ]
-        [ skip_holds_queue    => 1||0 ]
+        [ charge_cancel_fee       => 1||0, ]
+        [ cancellation_reason     => $cancellation_reason, ]
+        [ skip_holds_queue        => 1||0 ]
+        [ skip_hold_group_cleanup => 1||0 ]
     }
 );
 
@@ -798,6 +953,8 @@ sub cancel {
         }
     );
 
+    $self->cleanup_hold_group() unless $params->{skip_hold_group_cleanup};
+
     if ($autofill_next) {
         my ( undef, $next_hold ) = C4::Reserves::CheckReserves( $self->item );
         if ($next_hold) {
@@ -881,6 +1038,15 @@ sub fill {
             C4::Log::logaction( 'HOLDS', 'FILL', $self->id, $self, undef, $original )
                 if C4::Context->preference('HoldsLog');
 
+            # if this hold was part of a group, cancel other holds in the group
+            if ( $self->hold_group_id ) {
+                my @holds = $self->hold_group->holds->as_list;
+                foreach my $h (@holds) {
+                    $h->cancel( { skip_hold_group_cleanup => 1 } ) unless $h->reserve_id == $self->id;
+                }
+            }
+            $self->cleanup_hold_group();
+
             Koha::BackgroundJob::BatchUpdateBiblioHoldsQueue->new->enqueue(
                 { biblio_ids => [ $old_me->biblionumber ] } )
                 if C4::Context->preference('RealTimeHoldsQueue');
@@ -941,6 +1107,8 @@ sub revert_found {
 
             C4::Reserves::_FixPriority( { biblionumber => $self->biblionumber } );
 
+            $self->remove_as_hold_group_target();
+
             Koha::BackgroundJob::BatchUpdateBiblioHoldsQueue->new->enqueue( { biblio_ids => [ $self->biblionumber ] } )
                 if C4::Context->preference('RealTimeHoldsQueue');
         }
@@ -1052,6 +1220,25 @@ sub _set_default_expirationdate {
     }
 }
 
+=head3 hold_group
+
+    my $hold_group = $hold->hold_group;
+    my $hold_group_id = $hold_group->id if $hold_group;
+
+Return the Koha::HoldGroup object of a hold if part of a hold group
+
+=cut
+
+sub hold_group {
+    my ($self) = @_;
+
+    if ( $self->hold_group_id ) {
+        return Koha::HoldGroups->find( $self->hold_group_id );
+    }
+
+    return;
+}
+
 =head3 _move_to_old
 
 my $is_moved = $hold->_move_to_old;
