@@ -145,21 +145,24 @@ that we do not consider to be metadata
 
 sub metadata {
     my ( $self, $request ) = @_;
-    my $attrs    = $request->extended_attributes;
-    my $metadata = {};
-    my @ignore   = (
+
+    my @ignore = (
         'requested_partners', 'type', 'type_disclaimer_value', 'type_disclaimer_date', 'unauthenticated_first_name',
-        'unauthenticated_last_name', 'unauthenticated_email', 'historycheck_requests'
+        'unauthenticated_last_name', 'unauthenticated_email', 'historycheck_requests', 'copyrightclearance_confirmed'
     );
+
+    # Use database-level filtering instead of manual iteration
+    my $attrs = $request->extended_attributes->search( { type => { '-not_in' => \@ignore } } );
+
     my $core_fields = _get_core_fields();
+    my $metadata    = {};
+
     while ( my $attr = $attrs->next ) {
         my $type = $attr->type;
-        if ( !grep { $_ eq $type } @ignore ) {
-            my $name;
-            $name = $core_fields->{$type} || ucfirst($type);
-            $metadata->{$name} = $attr->value;
-        }
+        my $name = $core_fields->{$type} || ucfirst($type);
+        $metadata->{$name} = $attr->value;
     }
+
     return $metadata;
 }
 
@@ -479,46 +482,8 @@ sub edititem {
         # generate $request_details
         my $request_details = _get_request_details( $params, $other );
 
-        # We do this with a 'dump all and repopulate approach' inside
-        # a transaction, easier than catering for create, update & delete
-        my $dbh    = C4::Context->dbh;
-        my $schema = Koha::Database->new->schema;
-        $schema->txn_do(
-            sub {
-                # Delete all existing attributes for this request
-                $dbh->do(
-                    q|
-                    DELETE FROM illrequestattributes WHERE illrequest_id=?
-                |, undef, $request->id
-                );
-
-                # Insert all current attributes for this request
-                foreach my $attr ( keys %{$request_details} ) {
-                    my $value = $request_details->{$attr};
-                    if ( $value && length $value > 0 ) {
-                        if ( column_exists( 'illrequestattributes', 'backend' ) ) {
-                            my @bind = ( $request->id, 'Standard', $attr, $value, 0 );
-                            $dbh->do(
-                                q|
-                                INSERT INTO illrequestattributes
-                                (illrequest_id, backend, type, value, readonly) VALUES
-                                (?, ?, ?, ?, ?)
-                            |, undef, @bind
-                            );
-                        } else {
-                            my @bind = ( $request->id, $attr, $value, 0 );
-                            $dbh->do(
-                                q|
-                                INSERT INTO illrequestattributes
-                                (illrequest_id, type, value, readonly) VALUES
-                                (?, ?, ?, ?)
-                            |, undef, @bind
-                            );
-                        }
-                    }
-                }
-            }
-        );
+        # Update request attributes using modern ORM method
+        $request->add_or_update_attributes($request_details);
 
         ## -> create response.
         return {
@@ -716,19 +681,11 @@ sub migrate {
         my $original_attributes =
             $original_request->extended_attributes->search( { type => { '-in' => \@default_attributes } } );
 
-        my @request_details_array = map {
-            {
-                'type'  => $_->type,
-                'value' => $_->value,
-            }
-        } $original_attributes->as_list;
+        # Build attributes hash directly
+        my %attributes = map { $_->type => $_->value } $original_attributes->as_list;
+        $attributes{migrated_from} = $original_request->illrequest_id;
 
-        push @request_details_array, {
-            'type'  => 'migrated_from',
-            'value' => $original_request->illrequest_id,
-        };
-
-        $new_request->extended_attributes( \@request_details_array );
+        $new_request->add_or_update_attributes( \%attributes );
 
         return {
             error   => 0,
@@ -809,19 +766,8 @@ sub _set_requested_partners {
     # the time we get to this stage, any previous request
     # from partners would have had to be cancelled
     my ($args) = @_;
-    my $where = {
-        illrequest_id => $args->{request}->id,
-        type          => 'requested_partners'
-    };
-    Koha::ILL::Request::Attributes->search($where)->delete();
-    Koha::ILL::Request::Attribute->new(
-        {
-            illrequest_id => $args->{request}->id,
-            column_exists( 'illrequestattributes', 'backend' ) ? ( backend => "Standard" ) : (),
-            type  => 'requested_partners',
-            value => $args->{to}
-        }
-    )->store;
+
+    $args->{request}->add_or_update_attributes( { requested_partners => $args->{to} } );
 }
 
 =head3 _validate_borrower
@@ -1008,15 +954,11 @@ sub add_request {
         if column_exists( 'illrequests', 'batch_id' );
     $request->store;
 
-    my @request_details_array = map {
-        {
-            'type'  => $_,
-            'value' => $request_details->{$_},
-        }
-    } keys %{$request_details};
-    $request->extended_attributes( \@request_details_array );
+    $request->add_or_update_attributes($request_details);
     $request->add_unauthenticated_data( $params->{other} ) if $unauthenticated_request;
 
+    $request->after_created;
+
     return $request;
 }
 
