@@ -925,6 +925,7 @@ sub mark_completed {
         $self->status('COMP');
         $self->status_alias( $params->{status_alias} ) if $params->{status_alias};
         $self->completed( dt_from_string() );
+        $self->after_completed();
         $self->store;
         return {
             stage => 'commit',
@@ -1105,7 +1106,8 @@ sub backend_create {
         } elsif ( defined $params->{stage}
             && $params->{stage} eq 'copyrightclearance' )
         {
-            $params->{stage} = 'init';
+            $params->{copyrightclearance_confirmed} = 1;
+            $params->{stage}                        = 'init';
         }
     }
 
@@ -1303,6 +1305,90 @@ sub get_type_disclaimer_value {
     return $attr->value;
 }
 
+=head3 set_copyright_clearance_confirmed
+
+    $request->set_copyright_clearance_confirmed(1);
+
+Sets the copyright clearance confirmation status for the request.
+
+=cut
+
+sub set_copyright_clearance_confirmed {
+    my ( $self, $confirmed ) = @_;
+
+    # Normalize to boolean: 0 or 1
+    my $value = $confirmed ? 1 : 0;
+
+    $self->add_or_update_attributes( { copyrightclearance_confirmed => $value } );
+
+    return $self;
+}
+
+=head3 add_or_update_attributes
+
+    $request->add_or_update_attributes({
+        title => 'Book Title',
+        author => 'Author Name',
+        isbn => '1234567890'
+    });
+
+Adds new attributes or updates existing ones. More efficient than extended_attributes()
+for updating existing attributes as it avoids duplicate key errors.
+
+=cut
+
+sub add_or_update_attributes {
+    my ( $self, $attributes ) = @_;
+
+    return unless $attributes && ref($attributes) eq 'HASH';
+
+    my $schema = $self->_result->result_source->schema;
+    $schema->txn_do(
+        sub {
+            while ( my ( $type, $value ) = each %{$attributes} ) {
+
+                # Skip undefined or empty values
+                next unless defined $value && $value ne '';
+
+                my $attr = $self->extended_attributes->find( { type => $type } );
+
+                if ($attr) {
+
+                    # Update existing attribute only if value changed
+                    $attr->update( { value => $value } ) if $attr->value ne $value;
+                } else {
+
+                    # Create new attribute
+                    Koha::ILL::Request::Attribute->new(
+                        {
+                            illrequest_id => $self->id,
+                            type          => $type,
+                            value         => $value,
+                            backend       => $self->backend,
+                        }
+                    )->store;
+                }
+            }
+        }
+    );
+
+    return $self;
+}
+
+=head3 get_copyright_clearance_confirmed
+
+    my $confirmed = $request->get_copyright_clearance_confirmed;
+
+Returns 1 if copyright clearance has been confirmed, 0 otherwise.
+
+=cut
+
+sub get_copyright_clearance_confirmed {
+    my ($self) = @_;
+    my $attr = $self->extended_attributes->find( { type => 'copyrightclearance_confirmed' } );
+    return $attr ? ( $attr->value ? 1 : 0 ) : 0;
+}
+
 =head3 get_type_disclaimer_date
 
     my $type = $abstract->type_disclaimer_date();
@@ -2142,6 +2228,58 @@ sub store {
     return $ret;
 }
 
+=head3 after_completed
+
+    $request->after_completed;
+
+Actions to be done after the request has been completed
+
+=cut
+
+sub after_completed {
+    my ($self) = @_;
+
+    C4::Stats::UpdateStats(
+        {
+            borrowernumber => $self->borrowernumber // undef,
+            branch         => $self->branchcode,
+            categorycode   => $self->patron ? $self->patron->categorycode : undef,
+            ccode          => undef,
+            illrequest_id  => $self->illrequest_id,
+            itemnumber     => undef,
+            itemtype       => undef,
+            location       => undef,
+            type           => 'illreq_comp',
+        }
+    );
+}
+
+=head3 after_created
+
+    $request->after_created;
+
+Actions to be done after the request has been fully created
+
+=cut
+
+sub after_created {
+    my ($self) = @_;
+
+    C4::Stats::UpdateStats(
+        {
+            borrowernumber => $self->borrowernumber // undef,
+            branch         => $self->branchcode,
+            categorycode   => $self->patron ? $self->patron->categorycode : undef,
+            ccode          => undef,
+            illrequest_id  => $self->illrequest_id,
+            itemnumber     => undef,
+            itemtype       => undef,
+            location       => undef,
+            type           => 'illreq_created',
+        }
+    );
+}
+
 =head3 requested_partners
 
     my $partners_string = $request->requested_partners;
