@@ -1,13 +1,10 @@
 package Koha::Item::Search::Field;
 
 use Modern::Perl;
-
-our ( @ISA, @EXPORT_OK );
+use base 'Exporter';
 
 BEGIN {
-    require Exporter;
-    @ISA       = qw(Exporter);
-    @EXPORT_OK = qw(
+    our @EXPORT_OK = qw(
         AddItemSearchField
         ModItemSearchField
         DelItemSearchField
