@@ -18,21 +18,10 @@ package Koha::Patron::Debarments;
 # along with Koha; if not, see <https://www.gnu.org/licenses>.
 
 use Modern::Perl;
-
-use C4::Context;
-use C4::Log qw( logaction );
-
-use Koha::Database;
-use Koha::Patrons;
-use Koha::Patron::Restriction::Types;
-use Koha::Patron::Restrictions;
-
-our ( @ISA, @EXPORT_OK );
+use base 'Exporter';
 
 BEGIN {
-    require Exporter;
-    @ISA       = qw(Exporter);
-    @EXPORT_OK = qw(
+    our @EXPORT_OK = qw(
         AddDebarment
         DelDebarment
         ModDebarment
@@ -43,6 +32,14 @@ BEGIN {
     );
 }
 
+use C4::Context;
+use C4::Log qw( logaction );
+
+use Koha::Database;
+use Koha::Patrons;
+use Koha::Patron::Restriction::Types;
+use Koha::Patron::Restrictions;
+
 =head1 Koha::Patron::Debarments
 
 Koha::Patron::Debarments - Module for managing patron debarments
