@@ -21,17 +21,14 @@ package Koha::Util::FrameworkPlugin;
 #
 
 use Modern::Perl;
-
-use constant DEFAULT_008_POS_6_39 => 'b        |||||||| |||| 00| 0 eng d';
-
-our ( @ISA, @EXPORT_OK );
+use base 'Exporter';
 
 BEGIN {
-    require Exporter;
-    @ISA       = qw( Exporter );
-    @EXPORT_OK = qw( wrapper date_entered biblio_008 );
+    our @EXPORT_OK = qw( wrapper date_entered biblio_008 );
 }
 
+use constant DEFAULT_008_POS_6_39 => 'b        |||||||| |||| 00| 0 eng d';
+
 =head1 NAME
 
 Koha::Util::FrameworkPlugin - utility class with routines for framework plugins
