@@ -1,4 +1,5 @@
 import { defineConfig } from "cypress";
+import { devServer } from "cypress-rspack-dev-server";
 
 export default defineConfig({
     fixturesFolder: "t/cypress/fixtures",
@@ -21,4 +22,16 @@ export default defineConfig({
             apiPassword: "koha",
         },
     },
+
+    component: {
+        devServer(devServerConfig) {
+            return devServer({
+                ...devServerConfig,
+                rspackConfig: require("./rspack.config.js")[0],
+            });
+        },
+        indexHtmlFile: "t/cypress/support/component-index.html",
+        specPattern: "t/cypress/component/**/*.ts",
+        supportFile: "t/cypress/support/component.ts",
+    },
 });
