@@ -1,19 +1,25 @@
 use Modern::Perl;
 
 return {
-    bug_number => "24223",
+    bug_number  => "24223",
     description => "Move contents of OpacNav system preference into additional contents",
-    up => sub {
+    up          => sub {
         my ($args) = @_;
-        my ($dbh, $out) = @$args{qw(dbh out)};
+        my ( $dbh, $out ) = @$args{qw(dbh out)};
 
         # Get any existing value from the OpacNav system preference
-        my ($opacnav) = $dbh->selectrow_array( q|
+        my ($opacnav) = $dbh->selectrow_array(
+            q|
             SELECT value FROM systempreferences WHERE variable='OpacNav';
-        |);
-        if( $opacnav ){
+        |
+        );
+        if ($opacnav) {
+
             # If there is a value in the OpacNav preference, insert it into additional_contents
-            $dbh->do( "INSERT INTO additional_contents ( category, code, location, branchcode, title, content, lang, published_on ) VALUES ('html_customizations', 'OpacNav', 'OpacNav', NULL, ?, ?, 'default', CAST(NOW() AS date) )", undef, "OpacNav default", $opacnav );
+            $dbh->do(
+                "INSERT INTO additional_contents ( category, code, location, branchcode, title, content, lang, published_on ) VALUES ('html_customizations', 'OpacNav', 'OpacNav', NULL, ?, ?, 'default', CAST(NOW() AS date) )",
+                undef, "OpacNav default", $opacnav
+            );
 
             # Remove the OpacNav system preference
             $dbh->do("DELETE FROM systempreferences WHERE variable='OpacNav'");
@@ -22,4 +28,4 @@ return {
         }
 
     },
-}
+    }
