@@ -1,15 +1,17 @@
 use Modern::Perl;
 
 return {
-    bug_number => "16258",
+    bug_number  => "16258",
     description => "A preference to enabled/disable edifact",
-    up => sub {
+    up          => sub {
         my ($args) = @_;
-        my ($dbh, $out) = @$args{qw(dbh out)};
+        my ( $dbh, $out ) = @$args{qw(dbh out)};
 
-        $dbh->do(q{
+        $dbh->do(
+            q{
             INSERT IGNORE INTO systempreferences ( `variable`, `value`, `options`, `explanation`, `type` ) VALUES
             ('EDIFACT', '1', NULL, 'Enables EDIFACT acquisitions functions', 'YesNo')
-        });
+        }
+        );
     },
 };
