@@ -2,12 +2,14 @@ use Modern::Perl;
 
 return {
     bug_number  => "29129",
-    description => "Update the DisplayClearnScreenButton system pref to allow for a choice between ISSUESLIP and ISSUEQSLIP",
+    description =>
+        "Update the DisplayClearnScreenButton system pref to allow for a choice between ISSUESLIP and ISSUEQSLIP",
     up => sub {
         my ($args) = @_;
-        my ($dbh, $out) = @$args{qw(dbh out)};
+        my ( $dbh, $out ) = @$args{qw(dbh out)};
 
-        $dbh->do(q{
+        $dbh->do(
+            q{
             UPDATE systempreferences
             SET
                 options = 'no|issueslip|issueqslip',
@@ -17,6 +19,7 @@ return {
                               ELSE 'no'
                           END
             WHERE variable = 'DisplayClearScreenButton';
-        });
+        }
+        );
     },
 };
