@@ -27,5 +27,6 @@ INSERT INTO userflags (bit, flag, flagdesc, defaulton) VALUES
 (27, 'recalls', 'Recalls', 0),
 (28, 'erm', 'Manage electronic resources', 0),
 (29, 'loggedinlibrary', 'Change logged in library', 0),
-(30, 'preservation', 'Preservation module', 0)
+(30, 'preservation', 'Preservation module', 0),
+(31, 'sip2', 'SIP2 module', 0)
 ;
