@@ -39,6 +39,7 @@ INSERT INTO permissions (module_bit, code, description) VALUES
    ( 3, 'manage_additional_fields', 'Add, edit, or delete additional custom fields for baskets or subscriptions (also requires order_manage or edit_subscription permissions)'),
    ( 3, 'manage_keyboard_shortcuts', 'Manage keyboard shortcuts for the advanced cataloging editor'),
    ( 3, 'manage_smtp_servers', 'Manage SMTP servers configuration'),
+   ( 3, 'manage_file_transports', 'Manage file transports configuration'),
    ( 3, 'manage_background_jobs', 'Manage background jobs'),
    ( 3, 'manage_curbside_pickups', 'Manage curbside pickups'),
    ( 3, 'manage_search_filters', 'Manage custom search filters'),
@@ -53,6 +54,7 @@ INSERT INTO permissions (module_bit, code, description) VALUES
    ( 4, 'view_borrower_infos_from_any_libraries', 'View patron infos from any libraries'),
    ( 6, 'place_holds', 'Place holds for patrons'),
    ( 6, 'modify_holds_priority', 'Modify holds priority'),
+   ( 6, 'alter_hold_targets', 'Move holds between items and records'),
    ( 9, 'edit_catalogue', 'Edit catalog (Modify bibliographic/holdings data)'),
    ( 9, 'fast_cataloging', 'Fast cataloging'),
    ( 9, 'advanced_editor', 'Use the advanced cataloging editor (requires edit_catalogue)'),
@@ -114,6 +116,7 @@ INSERT INTO permissions (module_bit, code, description) VALUES
    (13, 'edit_patrons', 'Perform batch modification of patrons'),
    (13, 'delete_anonymize_patrons', 'Delete old borrowers and anonymize circulation history (deletes borrower checkout history)'),
    (13, 'batch_extend_due_dates', 'Perform batch extend due dates'),
+   (13, 'batch_modify_holds', 'Perform batch modification of holds'),
    (13, 'batch_upload_patron_images', 'Upload patron images in a batch or one at a time'),
    (13, 'schedule_tasks', 'Schedule tasks to run'),
    (13, 'items_batchmod', 'Perform batch modification of items'),
