@@ -691,6 +691,7 @@ function patron_autocomplete(node, options) {
     let link_to;
     let url_params;
     let on_select_callback;
+    let on_select_add_to;
 
     if (options) {
         if (options["link-to"]) {
@@ -702,6 +703,9 @@ function patron_autocomplete(node, options) {
         if (options["on-select-callback"]) {
             on_select_callback = options["on-select-callback"];
         }
+        if (options["on-select-add-to"]) {
+            on_select_add_to = options["on-select-add-to"];
+        }
     }
     return (node
         .autocomplete({
@@ -738,9 +742,30 @@ function patron_autocomplete(node, options) {
             },
             minLength: 3,
             select: function (event, ui) {
-                if (ui.item.link) {
+                if (on_select_add_to) {
+                    let container = on_select_add_to.container;
+
+                    const patron_name = $patron_to_html(ui.item);
+                    const node = `
+                      <div id='patron-detail-${ui.item.patron_id}' class='patron-detail-autocomplete-selection'>
+                        ${patron_name}
+                        (<a href='#' class='removePatron'>
+                          <i class='fa fa-trash-can' aria-hidden='true'></i> ${__("Remove")}
+                        </a>)
+                        <input type='hidden' name='${on_select_add_to.input_name}' value='${ui.item.patron_id}' />
+                      </div>
+                    `;
+
+                    $(container).append(node).parent().show(800);
+
+                    $(container).on("click", ".removePatron", function (e) {
+                        e.preventDefault();
+                        $(this).closest('div[id^="patron-detail-"]').remove();
+                    });
+                } else if (ui.item.link) {
                     window.location.href = ui.item.link;
-                } else if (on_select_callback) {
+                }
+                if (on_select_callback) {
                     return on_select_callback(event, ui);
                 }
             },
@@ -764,11 +789,6 @@ function patron_autocomplete(node, options) {
             item.link = null;
         }
 
-        var cardnumber = "";
-        if (item.cardnumber != "") {
-            // Display card number in parentheses if it exists
-            cardnumber = " (" + item.cardnumber + ") ";
-        }
         if (item.library_id == loggedInLibrary) {
             loggedInClass = "ac-currentlibrary";
         } else {
@@ -780,20 +800,12 @@ function patron_autocomplete(node, options) {
             .append(
                 "" +
                     (item.link ? '<a href="' + item.link + '">' : "<a>") +
-                    (item.surname ? item.surname.escapeHtml() : "") +
-                    ", " +
-                    (item.preferred_name
-                        ? item.preferred_name.escapeHtml()
-                        : item.firstname
-                          ? item.firstname.escapeHtml()
-                          : "") +
-                    " " +
-                    (item.middle_name ? item.middle_name.escapeHtml() : "") +
-                    " " +
-                    (item.other_name
-                        ? "(" + item.other_name.escapeHtml() + ")"
-                        : "") +
-                    cardnumber.escapeHtml() +
+                    $patron_to_html(item, {
+                        display_cardnumber: true,
+                        invert_name: true,
+                        showDiffFirstname:
+                            showPatronFirstnameIfDifferentThanPreferredname,
+                    }) +
                     " " +
                     (item.date_of_birth
                         ? $date(item.date_of_birth) +
@@ -1004,6 +1016,24 @@ function toggleBtnIcon(element, start, replacement) {
     });
 }
 
+/**
+ * Determines which patron page we are on based on the URL
+ * @return {string} The patron page we are on, "circ" or "borrower", or null
+ *                  if neither page is matched
+ */
+function holds_table_patron_page() {
+    var url = window.location.href;
+    if (
+        url.indexOf("/circ/circulation.pl?borrowernumber=") !== -1 ||
+        url.indexOf("/circ/circulation.pl?findborrower=") !== -1
+    )
+        return "circ";
+    else if (url.indexOf("/members/moremember.pl?borrowernumber=") !== -1)
+        return "borrower";
+
+    return null;
+}
+
 /**
  * Returns a roughly ideal position to scroll an element into view
  * @param {string} target - The HTML id of the element to scroll into view
