@@ -29,12 +29,14 @@ library.add(
 
 import App from "../components/Preservation/Main.vue";
 
+import "../../../css/vue.css";
+
 import { routes as routesDef } from "../routes/preservation";
 
 import { useMainStore } from "../stores/main";
 import { usePreservationStore } from "../stores/preservation";
 import { useNavigationStore } from "../stores/navigation";
-import i18n from "../i18n";
+import i18n from "@koha-vue/i18n";
 
 const pinia = createPinia();
 
