@@ -1,17 +1,15 @@
 import { markRaw } from "vue";
 
 import Home from "../components/Preservation/Home.vue";
-import TrainsList from "../components/Preservation/TrainsList.vue";
-import TrainsShow from "../components/Preservation/TrainsShow.vue";
-import TrainsFormAdd from "../components/Preservation/TrainsFormAdd.vue";
 import TrainsFormAddItem from "../components/Preservation/TrainsFormAddItem.vue";
 import TrainsFormAddItems from "../components/Preservation/TrainsFormAddItems.vue";
-import WaitingList from "../components/Preservation/WaitingList.vue";
 import Settings from "../components/Preservation/Settings.vue";
 import SettingsProcessingsShow from "../components/Preservation/SettingsProcessingsShow.vue";
 import SettingsProcessingsFormAdd from "../components/Preservation/SettingsProcessingsFormAdd.vue";
 
-import { $__ } from "../i18n";
+import ResourceWrapper from "../components/ResourceWrapper.vue";
+
+import { $__ } from "@koha-vue/i18n";
 
 export const routes = [
     {
@@ -39,21 +37,22 @@ export const routes = [
                 title: $__("Trains"),
                 icon: "fa fa-train",
                 is_end_node: true,
+                resource: "Preservation/TrainResource.vue",
                 children: [
                     {
                         path: "",
                         name: "TrainsList",
-                        component: markRaw(TrainsList),
+                        component: markRaw(ResourceWrapper),
                     },
                     {
                         path: ":train_id",
-                        title: $__("Show train"),
+                        title: "{name}",
                         is_end_node: true,
                         children: [
                             {
                                 path: "",
                                 name: "TrainsShow",
-                                component: markRaw(TrainsShow),
+                                component: markRaw(ResourceWrapper),
                             },
                             {
                                 path: "items",
@@ -84,14 +83,21 @@ export const routes = [
                     {
                         path: "add",
                         name: "TrainsFormAdd",
-                        component: markRaw(TrainsFormAdd),
+                        component: markRaw(ResourceWrapper),
                         title: $__("Add train"),
                     },
                     {
                         path: "edit/:train_id",
-                        name: "TrainsFormEdit",
-                        component: markRaw(TrainsFormAdd),
-                        title: $__("Edit train"),
+                        name: "TrainsFormAddEdit",
+                        component: markRaw(ResourceWrapper),
+                        title: "{name}",
+                        breadcrumbFormat: ({ match, params, query }) => {
+                            match.name = "TrainsShow";
+                            return match;
+                        },
+                        additionalBreadcrumbs: [
+                            { title: $__("Modify train"), disabled: true },
+                        ],
                     },
                 ],
             },
@@ -100,11 +106,12 @@ export const routes = [
                 title: $__("Waiting list"),
                 icon: "fa fa-recycle",
                 is_end_node: true,
+                resource: "Preservation/WaitingListResource.vue",
                 children: [
                     {
                         path: "",
                         name: "WaitingList",
-                        component: markRaw(WaitingList),
+                        component: markRaw(ResourceWrapper),
                     },
                 ],
             },
