@@ -160,9 +160,10 @@ $template->param( branch => $branch );
 #
 #
 if ( $op eq 'cud-place_reserve' ) {
-    my $reserve_cnt = 0;
+    my $add_to_hold_group = $query->param('add_to_hold_group');
+    my $reserve_cnt       = 0;
     if ($maxreserves) {
-        $reserve_cnt = $patron->holds->count;
+        $reserve_cnt = $patron->holds->count_holds;
     }
 
     # List is composed of alternating biblio/item/branch
@@ -194,6 +195,7 @@ if ( $op eq 'cud-place_reserve' ) {
     }
 
     my @failed_holds;
+    my @successful_hold_ids;
     while (@selectedItems) {
         my $biblioNum = shift(@selectedItems);
         my $itemNum   = shift(@selectedItems);
@@ -308,12 +310,15 @@ if ( $op eq 'cud-place_reserve' ) {
             );
             if ($reserve_id) {
                 ++$reserve_cnt;
+                push @successful_hold_ids, $reserve_id;
             } else {
                 push @failed_holds, 'not_placed';
             }
         }
     }
 
+    $patron->create_hold_group( \@successful_hold_ids ) if $add_to_hold_group;
+
     print $query->redirect( "/cgi-bin/koha/opac-user.pl?"
             . ( @failed_holds ? "failed_holds=" . join( '|', @failed_holds ) : q|| )
             . "&opac-user-holds=1" );
