@@ -110,6 +110,60 @@ if ( $op eq 'cud-move' ) {
             $next_priority, $first_priority, $last_priority
         );
     }
+} elsif ( $op eq 'cud-move_hold_item' or $op eq 'cud-move_hold_biblio' ) {
+    my @hold_ids              = $input->multi_param('move_hold_id');
+    my $original_biblionumber = $input->param('original_biblionumber');
+    my @moving_holds          = Koha::Holds->search(
+        { reserve_id => \@hold_ids },
+        { order_by   => { -asc => 'priority' } }
+    )->as_list;
+
+    my $new_biblionumber = $input->param('new_biblionumber');
+    my $target_biblio    = Koha::Biblios->find($new_biblionumber);
+
+    my %args = (
+        new_biblionumber => $new_biblionumber,
+    );
+
+    # Only pass new_itemnumber if this is an item level move
+    if ( $op eq 'cud-move_hold_item' ) {
+        $args{new_itemnumber} = $input->param('new_itemnumber');
+    }
+
+    my @success_messages;
+    my @error_messages;
+
+    foreach my $hold (@moving_holds) {
+        my $original_biblio = Koha::Biblios->find( $hold->biblionumber );
+
+        my $result = $hold->move_hold( \%args );
+
+        if ( $result->{success} ) {
+            push @success_messages, {
+                hold_id         => $hold->id,
+                success         => 1,
+                original_biblio => $original_biblio,
+                target_biblio   => $target_biblio,
+            };
+        } else {
+            push @error_messages, {
+                hold_id         => $hold->id,
+                success         => 0,
+                original_biblio => $original_biblio,
+                target_biblio   => $target_biblio,
+                error           => $result->{error},
+            };
+        }
+    }
+
+    #Fix the priority on the original record
+    C4::Reserves::_FixPriority( { biblionumber => $original_biblionumber } );
+
+    $template->param(
+        hold_move_successes => \@success_messages,
+        hold_move_failures  => \@error_messages,
+    );
+
 } elsif ( $op eq 'cud-cancel' ) {
     my $reserve_id          = $input->param('reserve_id');
     my $cancellation_reason = $input->param("cancellation-reason");
@@ -189,7 +243,7 @@ if ( $borrowernumber_hold && !$op ) {
     # we check the reserves of the user, and if they can reserve a document
     # FIXME At this time we have a simple count of reservs, but, later, we could improve the infos "title" ...
 
-    my $reserves_count = $patron->holds->count;
+    my $reserves_count = $patron->holds->count_holds;
 
     my $new_reserves_count = scalar(@biblionumbers);
 
@@ -677,6 +731,7 @@ if (   ( $findborrower && $borrowernumber_hold || $findclub && $club_hold )
                 $reserve{branchcode}       = $res->branchcode();
                 $reserve{non_priority}     = $res->non_priority();
                 $reserve{object}           = $res;
+                $reserve{hold_group_id}    = $res->hold_group_id;
 
                 if ( $holds_count_per_patron->{ $reserve{'borrowernumber'} } == 1 ) {
                     $reserve{'change_hold_type_allowed'} = 1;
