@@ -11,6 +11,11 @@ module.exports = [
                     __dirname,
                     "koha-tmpl/intranet-tmpl/prog/js/fetch"
                 ),
+                "@koha-vue": path.resolve(
+                    __dirname,
+                    "koha-tmpl/intranet-tmpl/prog/js/vue"
+                ),
+                "@cypress": path.resolve(__dirname, "t/cypress"),
             },
         },
         entry: {
@@ -22,6 +27,7 @@ module.exports = [
             acquisitions:
                 "./koha-tmpl/intranet-tmpl/prog/js/vue/modules/acquisitions.ts",
             islands: "./koha-tmpl/intranet-tmpl/prog/js/vue/modules/islands.ts",
+            sip2: "./koha-tmpl/intranet-tmpl/prog/js/vue/modules/sip2.ts",
         },
         output: {
             filename: "[name].js",
@@ -40,7 +46,7 @@ module.exports = [
                     options: {
                         experimentalInlineMatchResource: true,
                     },
-                    exclude: [path.resolve(__dirname, "t/cypress/")],
+                    //exclude: [path.resolve(__dirname, "t/cypress/")],
                 },
                 {
                     test: /\.ts$/,
@@ -166,6 +172,7 @@ module.exports = [
             "api-client.cjs":
                 "./koha-tmpl/intranet-tmpl/prog/js/fetch/api-client.js",
         },
+        devtool: false,
         output: {
             filename: "[name].js",
             path: path.resolve(__dirname, "t/cypress/plugins/dist/"),
