@@ -73,31 +73,30 @@ describe("License CRUD operations", () => {
             "have.length",
             4
         );
-        cy.get("#license_name").type(license.name);
-        cy.get("#license_description").type(license.description);
+        cy.get("#name").type(license.name);
+        cy.get("#description").type(license.description);
         cy.get("#licenses_add").contains("Submit").click();
-        cy.get("#license_type .vs__search").type(license.type + "{enter}", {
+        cy.get("#type .vs__search").type(license.type + "{enter}", {
             force: true,
         });
-        cy.get("#license_status .vs__search").type(license.status + "{enter}", {
+        cy.get("#status .vs__search").type(license.status + "{enter}", {
             force: true,
         });
 
         // vendors
-        cy.get("#license_vendor_id .vs__selected").should("not.exist"); //no vendor pre-selected for new license
+        cy.get("#vendor_id .vs__selected").should("not.exist"); //no vendor pre-selected for new license
 
         // vendor aliases
-        cy.get("#license_vendor_id .vs__search").click();
-        cy.get("#license_vendor_id #vs1__option-1").contains(vendors[1].name);
-        cy.get("#license_vendor_id #vs1__option-1 cite").contains(
+        cy.get("#vendor_id .vs__search").click();
+        cy.get("#vendor_id #vs3__option-1").contains(vendors[1].name);
+        cy.get("#vendor_id #vs3__option-1 cite").contains(
             vendors[1].aliases[0].alias
         );
 
-        cy.get("#license_vendor_id .vs__search").type(
-            vendors[0].name + "{enter}",
-            { force: true }
-        );
-        cy.get("#license_vendor_id .vs__selected").contains(vendors[0].name);
+        cy.get("#vendor_id .vs__search").type(vendors[0].name + "{enter}", {
+            force: true,
+        });
+        cy.get("#vendor_id .vs__selected").contains(vendors[0].name);
 
         cy.get("#started_on+input").click();
         cy.get(".flatpickr-calendar")
@@ -113,20 +112,20 @@ describe("License CRUD operations", () => {
             .click();
 
         // Add new document
-        cy.get("#documents").contains("Add new document").click();
-        cy.get("#document_0 input[id=file_0]").click();
-        cy.get("#document_0 input[id=file_0]").selectFile(
+        cy.get("#documents_relationship").contains("Add new document").click();
+        cy.get("#documents_0 input[id=file__0]").click();
+        cy.get("#documents_0 input[id=file__0]").selectFile(
             "t/cypress/fixtures/file.json"
         );
-        cy.get("#document_0 .file_information span").contains("file.json");
-        cy.get("#document_0 input[id=file_description_0]").type(
+        cy.get("#documents_0 .file_information span").contains("file.json");
+        cy.get("#documents_0 input[id=file_description__0]").type(
             "file description"
         );
-        cy.get("#document_0 input[id=physical_location_0]").type(
+        cy.get("#documents_0 input[id=documents_physical_location_0]").type(
             "file physical location"
         );
-        cy.get("#document_0 input[id=uri_0]").type("file URI");
-        cy.get("#document_0 input[id=notes_0]").type("file notes");
+        cy.get("#documents_0 input[id=documents_uri_0]").type("file URI");
+        cy.get("#documents_0 input[id=documents_notes_0]").type("file notes");
 
         // Submit the form, get 500
         cy.intercept("POST", "/api/v1/erm/licenses", {
@@ -179,36 +178,30 @@ describe("License CRUD operations", () => {
         cy.left_menu_active_item_is("Licenses");
 
         // Form has been correctly filled in
-        cy.get("#license_name").should("have.value", license.name);
+        cy.get("#name").should("have.value", license.name);
 
         //vendors
-        cy.get("#license_vendor_id .vs__selected").contains(
-            license.vendor[0].name
-        );
+        cy.get("#vendor_id .vs__selected").contains(license.vendor[0].name);
 
-        cy.get("#license_vendor_id .vs__search").type(
-            vendors[1].name + "{enter}",
-            { force: true }
-        );
+        cy.get("#vendor_id .vs__search").type(vendors[1].name + "{enter}", {
+            force: true,
+        });
 
         //vendor aliases
-        cy.get("#license_vendor_id .vs__search").click();
-        cy.get("#license_vendor_id #vs1__option-1").contains(vendors[1].name);
-        cy.get("#license_vendor_id #vs1__option-1 cite").contains(
+        cy.get("#vendor_id .vs__search").click();
+        cy.get("#vendor_id #vs3__option-1").contains(vendors[1].name);
+        cy.get("#vendor_id #vs3__option-1 cite").contains(
             vendors[1].aliases[0].alias
         );
 
-        cy.get("#license_description").should(
-            "have.value",
-            license.description
-        );
-        cy.get("#license_type .vs__selected").contains("Local");
-        cy.get("#license_status .vs__selected").contains("Active");
+        cy.get("#description").should("have.value", license.description);
+        cy.get("#type .vs__selected").contains("Local");
+        cy.get("#status .vs__selected").contains("Active");
         cy.get("#started_on").invoke("val").should("eq", dates["today_iso"]);
         cy.get("#ended_on").invoke("val").should("eq", dates["tomorrow_iso"]);
 
         // Test related document
-        cy.get("#document_0 .file_information span").contains("file.json");
+        cy.get("#documents_0 .file_information span").contains("file.json");
 
         // Submit the form, get 500
         cy.intercept("PUT", "/api/v1/erm/licenses/*", {
