@@ -72,9 +72,11 @@ describe("Infinite scroll", () => {
         cy.visit("/cgi-bin/koha/erm/agreements");
         cy.contains("New agreement").click();
 
-        cy.get("#agreement_licenses").contains("Add new license").click();
-        cy.get("#license_id_0 .vs__open-indicator").click();
-        cy.get("#license_id_0").find("li").as("options");
+        cy.get("#agreement_licenses_relationship")
+            .contains("Add new license")
+            .click();
+        cy.get("#agreement_licenses_license_id_0 .vs__open-indicator").click();
+        cy.get("#agreement_licenses_license_id_0").find("li").as("options");
         cy.get("@options").should("have.length", 20);
 
         cy.intercept("GET", "/api/v1/erm/licenses*", {
@@ -136,23 +138,22 @@ describe("Infinite scroll", () => {
         cy.visit("/cgi-bin/koha/erm/agreements");
         cy.contains("New agreement").click();
 
-        cy.get("#agreement_licenses").contains("Add new license").click();
-        cy.get("#license_id_0 .vs__open-indicator").click();
+        cy.get("#agreement_licenses_relationship")
+            .contains("Add new license")
+            .click();
+        cy.get("#agreement_licenses_license_id_0 .vs__open-indicator").click();
 
-        cy.get("#agreement_license_0 #license_id_0 .vs__dropdown-menu li")
+        cy.get(
+            "#agreement_licenses_0 #agreement_licenses_license_id_0 .vs__dropdown-menu li"
+        )
             .eq(0)
             .click({ force: true }); //click first license suggestion
 
         // Fill in the other required fields
-        cy.get("#agreement_name").type(agreement.name);
-        cy.get("#agreement_status .vs__search").type(
-            agreement.status + "{enter}",
-            { force: true }
-        );
-        cy.get("#agreement_license_0 #license_status_0 .vs__search").type(
-            agreement.agreement_licenses[0].status + "{enter}",
-            { force: true }
-        );
+        cy.get("#name").type(agreement.name);
+        cy.get("#status .vs__search").type(agreement.status + "{enter}", {
+            force: true,
+        });
 
         cy.intercept("POST", "/api/v1/erm/agreements", {
             statusCode: 201,
@@ -199,10 +200,12 @@ describe("Infinite scroll", () => {
         cy.visit("/cgi-bin/koha/erm/agreements");
         cy.contains("New agreement").click();
 
-        cy.get("#agreement_licenses").contains("Add new license").click();
-        cy.get("#license_id_0 .vs__open-indicator").click();
+        cy.get("#agreement_licenses_relationship")
+            .contains("Add new license")
+            .click();
+        cy.get("#agreement_licenses_license_id_0 .vs__open-indicator").click();
         cy.wait("@getPageOne");
-        cy.get("#license_id_0").find("li").as("options");
+        cy.get("#agreement_licenses_license_id_0").find("li").as("options");
         cy.get("@options").should("have.length", 20);
         cy.intercept("GET", "/api/v1/erm/licenses*", {
             statusCode: 200,
@@ -214,7 +217,7 @@ describe("Infinite scroll", () => {
         }).as("getPageTwo");
         // Scroll the dropdown
         cy.get(
-            "#agreement_license_0 #license_id_0 .vs__dropdown-menu"
+            "#agreement_licenses_0 #agreement_licenses_license_id_0 .vs__dropdown-menu"
         ).scrollTo("bottom");
         cy.wait("@getPageTwo");
         cy.intercept("GET", "/api/v1/erm/licenses*", {
@@ -227,7 +230,7 @@ describe("Infinite scroll", () => {
         }).as("finalPage");
         // Scroll the dropdown again
         cy.get(
-            "#agreement_license_0 #license_id_0 .vs__dropdown-menu"
+            "#agreement_licenses_0 #agreement_licenses_license_id_0 .vs__dropdown-menu"
         ).scrollTo("bottom");
         cy.wait("@finalPage");
         cy.intercept("GET", "/api/v1/erm/licenses*", {
@@ -250,10 +253,9 @@ describe("Infinite scroll", () => {
             },
         }).as("searchFilter");
         // Select a  license that is not in the first page of results
-        cy.get("#agreement_license_0 #license_id_0 .vs__search").type(
-            "License 50",
-            { force: true }
-        );
+        cy.get(
+            "#agreement_licenses_0 #agreement_licenses_license_id_0 .vs__search"
+        ).type("License 50", { force: true });
         cy.wait([
             "@searchFilter",
             "@searchFilter",
@@ -266,15 +268,14 @@ describe("Infinite scroll", () => {
             "@searchFilter",
             "@searchFilter",
         ]);
-        cy.get("#agreement_license_0 #license_id_0 .vs__search").type(
-            "{enter}",
-            { force: true }
-        );
-        cy.get("#agreement_license_0").contains("License 50");
+        cy.get(
+            "#agreement_licenses_0 #agreement_licenses_license_id_0 .vs__search"
+        ).type("{enter}", { force: true });
+        cy.get("#agreement_licenses_0").contains("License 50");
 
         // Re-open the dropdown, License 50 will no longer be in the dataset but the label should still show
         // First we will click into the notes field to ensure the dropdown is closed
-        cy.get("#license_notes_0").click();
+        cy.get("#agreement_licenses_notes_0").click();
         cy.intercept("GET", "/api/v1/erm/licenses*", {
             statusCode: 200,
             body: pageOne,
@@ -283,12 +284,12 @@ describe("Infinite scroll", () => {
                 "X-Total-Count": "60",
             },
         }).as("resetDropdown");
-        cy.get("#license_id_0 .vs__open-indicator").click();
+        cy.get("#agreement_licenses_license_id_0 .vs__open-indicator").click();
         cy.wait("@resetDropdown");
         // Close the dropdown
-        cy.get("#license_id_0 .vs__open-indicator").click();
-        cy.get("#license_notes_0").click();
-        cy.get("#agreement_license_0").contains("License 50");
+        cy.get("#agreement_licenses_license_id_0 .vs__open-indicator").click();
+        cy.get("#agreement_licenses_notes_0").click();
+        cy.get("#agreement_licenses_0").contains("License 50");
 
         // Select a different license
         cy.intercept("GET", "/api/v1/erm/licenses*", {
@@ -310,11 +311,10 @@ describe("Infinite scroll", () => {
                 "X-Total-Count": "60",
             },
         }).as("secondSearchFilter");
-        cy.get("#license_id_0 .vs__open-indicator").click();
-        cy.get("#agreement_license_0 #license_id_0 .vs__search").type(
-            "License 10",
-            { force: true }
-        );
+        cy.get("#agreement_licenses_license_id_0 .vs__open-indicator").click();
+        cy.get(
+            "#agreement_licenses_0 #agreement_licenses_license_id_0 .vs__search"
+        ).type("License 10", { force: true });
         cy.wait([
             "@secondSearchFilter",
             "@secondSearchFilter",
@@ -327,11 +327,10 @@ describe("Infinite scroll", () => {
             "@secondSearchFilter",
             "@secondSearchFilter",
         ]);
-        cy.get("#agreement_license_0 #license_id_0 .vs__search").type(
-            "{enter}",
-            { force: true }
-        );
-        cy.get("#agreement_license_0").contains("License 10");
+        cy.get(
+            "#agreement_licenses_0 #agreement_licenses_license_id_0 .vs__search"
+        ).type("{enter}", { force: true });
+        cy.get("#agreement_licenses_0").contains("License 10");
     });
 
     it("Should correctly display the label when editing", () => {
@@ -347,27 +346,19 @@ describe("Infinite scroll", () => {
         }).as("get-vendor-options");
 
         // Intercept initial /agreements request once
-        cy.intercept(
-            {
-                method: "GET",
-                url: "/api/v1/erm/agreements*",
-                times: 1,
-            },
-            {
-                body: agreements,
-            }
-        );
+        // and
         // Intercept follow-up 'search' request after entering /agreements
-        cy.intercept("GET", "/api/v1/erm/agreements?_page*", {
+        cy.intercept("GET", "/api/v1/erm/agreements*", {
             statusCode: 200,
             body: agreements,
             headers: {
                 "X-Base-Total-Count": "1",
                 "X-Total-Count": "1",
             },
-        }).as("get-single-agreement-search-result");
+        }).as("get-agreements");
         cy.visit("/cgi-bin/koha/erm/agreements");
-        cy.wait("@get-single-agreement-search-result");
+        cy.wait("@get-agreements");
+        cy.wait("@get-agreements");
 
         // Intercept request after edit click
         cy.intercept("GET", "/api/v1/erm/agreements/*", agreement).as(
@@ -398,11 +389,11 @@ describe("Infinite scroll", () => {
         cy.wait("@get-agreement");
 
         // Licenses should be labelled correctly
-        cy.get("#agreement_license_0 #license_id_0 .vs__selected").contains(
-            "first license name"
-        );
-        cy.get("#agreement_license_1 #license_id_1 .vs__selected").contains(
-            "second license name"
-        );
+        cy.get(
+            "#agreement_licenses_0 #agreement_licenses_license_id_0 .vs__selected"
+        ).contains("first license name");
+        cy.get(
+            "#agreement_licenses_1 #agreement_licenses_license_id_1 .vs__selected"
+        ).contains("second license name");
     });
 });
