@@ -68,25 +68,31 @@ function get_items() {
             biblio: {
                 biblio_id: 1,
                 title: "a biblio title",
+                author: "an author",
             },
             external_id: "bc_1",
             item_id: 1,
+            callnumber: "cn_1",
         },
         {
             biblio: {
                 biblio_id: 2,
                 title: "an other biblio title",
+                author: "another author",
             },
             external_id: "bc_2",
             item_id: 2,
+            callnumber: "cn_2",
         },
         {
             biblio: {
                 biblio_id: 3,
                 title: "yet an other biblio title",
+                author: "yet another author",
             },
             external_id: "bc_3",
             item_id: 3,
+            callnumber: "cn_3",
         },
     ];
 }
@@ -128,6 +134,8 @@ function get_train_items() {
     train_item_1.processing_id = 1;
     train_item_1.processing = get_processings()[0];
     train_item_1.item_id = 1;
+    train_item_1.train_item_id = 1;
+    train_item_1.user_train_item_id = 1;
 
     let train_item_2 = get_items()[1];
     let processing_attributes = get_attributes();
@@ -158,6 +166,8 @@ function get_train_items() {
     train_item_2.processing_id = 1;
     train_item_2.processing = get_processings()[0];
     train_item_2.item_id = 2;
+    train_item_2.train_item_id = 2;
+    train_item_2.user_train_item_id = 2;
 
     let train_item_3 = get_items()[0];
     let processing_attributes = get_other_attributes();
@@ -181,6 +191,8 @@ function get_train_items() {
     train_item_3.processing_id = 2;
     train_item_3.processing = get_processings()[1];
     train_item_3.item_id = 3;
+    train_item_3.train_item_id = 3;
+    train_item_3.user_train_item_id = 3;
 
     return [train_item_1, train_item_2, train_item_3];
 }
@@ -302,8 +314,8 @@ describe("Trains", () => {
         cy.visit("/cgi-bin/koha/preservation/trains");
         let train = get_train();
         cy.contains("New train").click();
-        cy.get("#train_name").type(train.name);
-        cy.get("#train_description").type(train.description);
+        cy.get("#name").type(train.name);
+        cy.get("#description").type(train.description);
         // Confirm that the default not_for_loan is selected
         cy.get("#not_for_loan .vs__selected").contains(
             "In preservation external"
@@ -312,7 +324,7 @@ describe("Trains", () => {
         cy.get("#not_for_loan .vs__search").type(
             "In preservation other{enter}"
         );
-        cy.get("#train_default_processing .vs__search").type(
+        cy.get("#default_processing_id .vs__search").type(
             "new processing{enter}"
         );
 
@@ -351,12 +363,12 @@ describe("Trains", () => {
         cy.intercept("GET", "/api/v1/preservation/processings*", processings);
         cy.visit("/cgi-bin/koha/preservation/trains");
         cy.get("#trains_list table tbody tr:first").contains("Edit").click();
-        cy.get("#train_name").should("have.value", train.name);
-        cy.get("#train_description").should("have.value", train.description);
+        cy.get("#name").should("have.value", train.name);
+        cy.get("#description").should("have.value", train.description);
         cy.get("#not_for_loan .vs__selected").contains(
             "In preservation external"
         );
-        cy.get("#train_default_processing .vs__selected").contains(
+        cy.get("#default_processing_id .vs__selected").contains(
             train.default_processing.name
         );
 
@@ -397,10 +409,7 @@ describe("Trains", () => {
         cy.intercept("GET", "/api/v1/preservation/trains/*", train);
         cy.visit("/cgi-bin/koha/preservation/trains");
         let name_link = cy.get("#trains_list table tbody tr:first td:first a");
-        name_link.should(
-            "have.text",
-            train.name + " (#" + train.train_id + ")"
-        );
+        name_link.should("have.text", train.train_id);
         name_link.click();
         cy.get("#trains_show h2").contains("Train #" + train.train_id);
 
@@ -571,8 +580,9 @@ describe("Trains", () => {
             "GET",
             "/api/v1/preservation/trains/" + train.train_id,
             train_with_one_item
-        );
+        ).as("get-train");
         cy.contains("Submit").click();
+        cy.wait("@get-train");
         cy.get("#trains_show").contains("Showing 1 to 1 of 1 entries");
 
         let train_with_2_items = Object.assign({}, train);
@@ -633,7 +643,7 @@ describe("Trains", () => {
             { item_id: 2 },
         ]);
 
-        cy.get("#waiting-list").contains("Add to waiting list").click();
+        cy.get("#items_list").contains("Add to waiting list").click();
         cy.get("#barcode_list").type("bc_1\nbc_2");
         cy.contains("Save").click();
         cy.wait("@get-items");
@@ -641,7 +651,7 @@ describe("Trains", () => {
             "2 new items added."
         );
 
-        cy.get("#waiting-list").contains("Add to waiting list").click();
+        cy.get("#items_list").contains("Add to waiting list").click();
         cy.get("#barcode_list").type("bc_1\nbc_2\nbc_3");
         cy.contains("Save").click();
         cy.wait("@get-items");
@@ -650,7 +660,9 @@ describe("Trains", () => {
         );
         cy.get("#close_modal").click();
         cy.contains("Add last 2 items to a train").click();
-        cy.get("#train_id .vs__search").type(train.name + "{enter}");
+        cy.get("#train_id_selected_for_add .vs__search").type(
+            train.name + "{enter}"
+        );
         cy.intercept("GET", "/api/v1/items*", {
             statusCode: 200,
             body: get_items().filter(
@@ -679,7 +691,7 @@ describe("Trains", () => {
                 is_system: false,
             },
         ]);
-        cy.get("#add_to_train .approve").click();
+        cy.get("#confirmation").contains("Save").click();
         train.items = get_train_items().filter(
             train_item => train_item.item_id == 1 || train_item.item_id == 2
         );
